<?php

function activetl_settings_form($form, &$form_state) {
	$content_types = node_type_get_types();
	$content_types_options = array();
	foreach ($content_types as $item) {
		$content_types_options[$item->type] = $item->name;
	}
	$form['activetl_content_types'] = array(
		'#title' => t('Content types'),
		'#type' => 'checkboxes',
		'#options' => $content_types_options,
		'#default_value' => variable_get('activetl_content_types', array()),
		'#description' => t('Choose content types to activate taxonomy links'),
	);
	
	$vocs = taxonomy_get_vocabularies();
	$vocs_options = array();
	foreach ($vocs as $item) {
		$vocs_options[$item->vid] = $item->name;
	}
	$form['activetl_vocs'] = array(
		'#title' => t('Vocabularies'),
		'#type' => 'checkboxes',
		'#options' => $vocs_options,
		'#default_value' => variable_get('activetl_vocs', array()),
    '#description' => t('Choose taxonomy vocabularies, which terms you\'d like to process'),
	);
	return system_settings_form($form);
}

function activetl_batch_process_form($form, &$forms_state) {
	$content_types = node_type_get_types();
	$activetl_content_types = variable_get('activetl_content_types', array());
	$unprocessed_nodes = activetl_db_unrocessed_nodes_select($activetl_content_types);
	$unprocessed_options = array();
	foreach ($unprocessed_nodes as $item) {
		if (!isset($unprocessed_options[$item->type])) {
			$unprocessed_options[$item->type] = 0;
		}
		$unprocessed_options[$item->type]++;
	}
	$content_types_options = array();
	foreach ($unprocessed_options as $key => $item) {
		$content_types_options[$key] = $content_types[$key]->name . " ($unprocessed_options[$key])";
	}
	$form['unprocessed_nodes_count'] = array(
		'#type' => 'item',
		'#markup' => t('There are !count nodes unprocessed', array('!count' => count($unprocessed_nodes))),
	);
	if (!empty($content_types_options)) {
		$form['content_types_to_process'] = array(
			'#title' => t('Content types to process'),
			'#type' => 'checkboxes',
			'#options' => $content_types_options,
			'#description' => t('Choose content types you\'d like to process via active taxonomy links'),
		);
	}
	$form['submit'] = array(
		'#type' => 'submit',
		'#value' => t('Process nodes'),
	);
	return $form;
}

function activetl_batch_process_form_submit($form, $form_state) {
	if (isset($form_state['values']['content_types_to_process'])) {
		$content_types_to_process = $form_state['values']['content_types_to_process'];
		$unprocessed_nodes = activetl_db_unrocessed_nodes_select($content_types_to_process);
		$unprocessed_nodes_nids = array();
		foreach ($unprocessed_nodes as $item) {
			$item = (array)$item;
			$unprocessed_nodes_nids[] = $item['nid'];
		}
		if (!empty($unprocessed_nodes_nids)) {
			$nodes = node_load_multiple($unprocessed_nodes_nids);
			foreach ($nodes as $node) {
				activetl_node_process($node, 'body');
			}
		}
	}
	else {
		drupal_set_message(t('No nodes to process.'));
	}
}

function activetl_batch_unprocess_form($form, &$form_state) {
	$content_types = node_type_get_types();
	$processed_nodes_info = activetl_db_processed_nodes_info_select();
	$processed_options = array();
	foreach ($processed_nodes_info as $item) {
		if (!isset($processed_options[$item->type])) {
			$processed_options[$item->type] = 0;
		}
		$processed_options[$item->type]++;
	}
	$content_types_options = array();
	foreach ($processed_options as $key => $item) {
		$content_types_options[$key] = $content_types[$key]->name . " ($processed_options[$key])";
	}
	$form['processed_nodes_count'] = array(
		'#type' => 'item',
		'#markup' => t('There are !count nodes processed by active taxonomy links', array('!count' => count($processed_nodes_info))),
	);
	if (!empty($content_types_options)) {
		$form['content_types_to_unprocess'] = array(
			'#title' => t('Content types to unprocess'),
			'#type' => 'checkboxes',
			'#options' => $content_types_options,
			'#description' => t('Choose content types you\'d like to unprocess'),
		);
	}
	$form['submit'] = array(
		'#type' => 'submit',
		'#value' => t('Unprocess nodes'),
	);
	return $form;
}

function activetl_batch_unprocess_form_submit($form, $form_state) {
	if (isset($form_state['values']['content_types_to_unprocess'])) {
		$content_types_to_unprocess = $form_state['values']['content_types_to_unprocess'];
		$processed_nodes_info = activetl_db_processed_nodes_info_select();
    $processed_nodes_nids = array();
		foreach ($processed_nodes_info as $item) {
			if (in_array($item->type, $content_types_to_unprocess, TRUE)) {
        $processed_nodes_nids[] = $item->nid;
      }
		}
    if (!empty($processed_nodes_nids)) {
      $nodes = node_load_multiple($processed_nodes_nids);
      foreach ($nodes as $node) {
        activetl_node_unprocess($node, 'body');
      }
    }
	}
	else {
		drupal_set_message(t('No nodes to unprocess.'));
	}
}